#
# spec file for package sqlite2
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           sqlite2
BuildRequires:  libtool
BuildRequires:  readline-devel
BuildRequires:  tcl-devel
BuildRequires:  update-desktop-files
Summary:        Embeddable SQL Database Engine
License:        SUSE-Public-Domain
Group:          Productivity/Databases/Servers
# bug437293
%ifarch ppc64
Obsoletes:      sqlite2-64bit
%endif
#
Url:            http://www.sqlite.org/
Version:        2.8.17
Release:        lp156.1.1
Source0:        http://www.sqlite.org/sqlite-%version.tar.bz2
Source1:        sqlite2.desktop
Source2:        baselibs.conf
Patch0:         sqlite.diff
Patch1:         sqlite2-tcl.diff
Patch2:         detect_sqlite3.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
SQLite is a C library that implements an embeddable SQL database
engine. Programs that link with the SQLite library can have SQL
database access without running a separate RDBMS process.

SQLite is not a client library used to connect to a big database
server. SQLite is the server and the SQLite library reads and writes
directly to and from the database files on disk.

SQLite can be used via the sqlite command line tool or via any
application that supports the Qt database plug-ins.



Authors:
--------
    D. Richard Hipp <drh@hwaci.com>

%package devel
Summary:        Embeddable SQL Database Engine
Group:          Productivity/Databases/Servers
Requires:       glibc-devel
Requires:       sqlite2 = %version
# bug437293
%ifarch ppc64
Obsoletes:      sqlite2-devel-64bit
%endif
#

%description devel
SQLite is a C library that implements an embeddable SQL database
engine. Programs that link with the SQLite library can have SQL
database access without running a separate RDBMS process.

SQLite is not a client library used to connect to a big database
server. SQLite is the server and the SQLite library reads and writes
directly to and from the database files on disk.

SQLite can be used via the sqlite command line tool or via any
application that supports the Qt database plug-ins.



Authors:
--------
    D. Richard Hipp <drh@hwaci.com>

%prep
%setup -q -n sqlite-%version
# sqlite.diff
%patch0
# sqlite2-tcl.diff
%patch1
# detect_sqlite3.patch
%patch2 -p1

%ifarch s390 s390x 
# some (minor ?) miscalculations with float values on these platforms
# needs to be checked deeper later
rm test/printf.test
%endif
%ifarch ppc
# minor miscalculation
rm test/format3.test
%endif
%ifarch ia64 x86_64 s390x sparc64 mips64 axp ppc64 ppc64le aarch64
# these test cases are not 64bit clean (more a Tcl issue than a sqlite one)
rm test/format3.test test/pager.test test/btree*.test test/version.test test/pragma.test
%endif
# FIXME: the test itself runs, but it doesn't work, when the
#        join3 did run before. no idea yet.
rm test/tclsqlite.test
# does not work due to our ulimits in our build system
rm test/bigfile.test
autoreconf -fi

%build
  export CFLAGS="$RPM_OPT_FLAGS -DNDEBUG=1 -fno-strict-aliasing -DUSE_INTERP_RESULT"
  export CXXFLAGS="$CFLAGS -fno-strict-aliasing"
  mkdir build
  cd build
  ln -s ../VERSION .
  ../configure \
    --prefix=/usr \
    --libdir=%_libdir \
    --mandir=%_mandir \
    --enable-utf8 \
    --sysconfdir=/etc/ \
	--disable-static \
	--with-pic 
  %{__make} %{?_smp_mflags}
  make doc

%check
  cd build
  make fulltest

%install
  cd build
  make DESTDIR="$RPM_BUILD_ROOT" install
  install -d $RPM_BUILD_ROOT%_mandir/man1/
  install -m 0644 ../sqlite.1 $RPM_BUILD_ROOT%_mandir/man1/
  #
  # install the susehelp meta file
  mkdir -p $RPM_BUILD_ROOT/usr/share/susehelp/meta/Development/Libraries/
  install -m 0644 %SOURCE1 \
        $RPM_BUILD_ROOT/usr/share/susehelp/meta/Development/Libraries/
  %suse_update_desktop_file $RPM_BUILD_ROOT/usr/share/susehelp/meta/Development/Libraries/sqlite2.desktop
%{__rm} -f %{buildroot}%{_libdir}/*.la

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
/usr/bin/sqlite
%_mandir/man1/*
%_libdir/libsqlite.so.*

%files devel
%defattr(-,root,root)
%doc build/doc/*
%doc /usr/share/susehelp
/usr/include/sqlite.h
%_libdir/libsqlite.so
%_libdir/pkgconfig/sqlite.pc

%changelog
* Sun Dec 15 2013 uweigand@de.ibm.com
- Add ppc64le to the list of 64-bit architectures
* Thu Aug  1 2013 max@suse.com
- Allow and fix building against Tcl 8.6.
* Wed Jun 19 2013 schwab@suse.de
- Add aarch64 to the list of 64-bit architectures
* Mon Dec 31 2012 jw@suse.com
- detect_sqlite3.patch
  Trivial usability feature: avoid a false error message
  "file is encrypted or is not a database" if it is valid sqlite3
  Upstreamed as
  http://www.sqlite.org/src/tktview/030632f55ba0c98c273ddabdea417b996897eeb3
* Wed Nov 23 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Thu Jul  1 2010 jengelh@medozas.de
- use %%_smp_mflags
* Sat Dec 19 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Sun Feb 22 2009 crrodriguez@suse.de
- remove sttaic libraries and "la" files
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Wed May 14 2008 schwab@suse.de
- Fix broken cast.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Mon Apr  7 2008 max@suse.de
- Fix the test suite for Tcl 8.5 (sqlite2-tcl.diff).
* Tue Nov 14 2006 adrian@suse.de
- apply additional pointer check for avoiding crash within php5
  (#218295)
* Fri Nov 10 2006 adrian@suse.de
- fix permissions of man page file
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 adrian@suse.de
- fix file conflict between sqlite-devel and sqlite2-devel (#140301)
* Wed Jan  4 2006 adrian@suse.de
- update to version 2.8.17
  * bugfix release
* Wed Feb 16 2005 gekker@suse.de
- Change requires in -devel package to depend on sqlite2
* Wed Feb 16 2005 adrian@suse.de
- update to version 2.8.16
  * contains a criticial bugsfix, which can corrupted the database
    when using the VACUUM command
* Tue Feb  1 2005 sbrabec@suse.cz
- Worked around missing version in pc file.
* Mon Nov 29 2004 adrian@suse.de
- change this package to an compatibility package
* Mon Nov 15 2004 adrian@suse.de
- add susehelp desktop file for developer documentation
* Mon Nov 15 2004 adrian@suse.de
- fix libdir path in .la file for lib64 systems
* Mon Oct 25 2004 adrian@suse.de
- enable utf-8 support
* Fri Jul 30 2004 adrian@suse.de
- run "make alltest"
* Thu Jul 29 2004 adrian@suse.de
- update to version 2.8.15
- disable wrong tcl test case on 64bit
* Mon Jun 21 2004 adrian@suse.de
- update to version 2.8.14
* Tue Jun  1 2004 adrian@suse.de
- package sqlite man page
* Fri Apr 23 2004 adrian@suse.de
- update to version 2.8.13
* Mon Mar  1 2004 adrian@suse.de
- disable format3 test case for ppc for now
* Sun Feb 29 2004 adrian@suse.de
- update to version 2.8.12
- add usual 64bit fixes
- add -fno-strict-aliasing
- disable bigfile test case due to limits in autobuild
* Thu Jan 22 2004 adrian@suse.de
- update to version 2.8.11
  * one testcase fails on ppc, our ppc people will have a look
* Mon Dec 29 2003 adrian@suse.de
- update to version 2.8.8
  * several 64 bit fixes have been merged, some more are needed now
- ignore some not exact matching float test cases on s390*
- enable threading support
* Tue Dec  2 2003 adrian@suse.de
- initial package of version 2.8.6
- a number of 64bit fixes
- some test cases got disabled, because they use an invalid Tcl
  Interface for 64bit
